@@ -1,5 +1,5 @@
 package Cogit::DirectoryEntry;
-$Cogit::DirectoryEntry::VERSION = '0.001000';
+$Cogit::DirectoryEntry::VERSION = '0.001001';
 use Moo;
 use MooX::Types::MooseLike::Base 'Str', 'InstanceOf';
 use namespace::clean;
@@ -47,15 +47,15 @@ Cogit::DirectoryEntry
 
 =head1 VERSION
 
-version 0.001000
+version 0.001001
 
 =head1 AUTHOR
 
-Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
+Arthur Axel "fREW" Schmidt <cogit@afoolishmanifesto.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2017 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
