@@ -1,5 +1,5 @@
 package Cogit::Protocol::File;
-$Cogit::Protocol::File::VERSION = '0.001000';
+$Cogit::Protocol::File::VERSION = '0.001001';
 use Moo;
 use MooX::Types::MooseLike::Base 'Str';
 use IPC::Open2;
@@ -43,15 +43,15 @@ Cogit::Protocol::File
 
 =head1 VERSION
 
-version 0.001000
+version 0.001001
 
 =head1 AUTHOR
 
-Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
+Arthur Axel "fREW" Schmidt <cogit@afoolishmanifesto.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2017 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
